# MPT5
## This Project is a platform for make application  with simple  GUI  and developable application 
### you can use python source code , database and Machine learning algorithms together in one place

Start from the beginning with your own and others' codes

![](docs/Help/images/0/1b.jpg)

Introduction
===========
This is a new idea for made an application and develop base on GUI and Relation between components,
you can start work and change for each Time, each Position, each Conditions, with or without other, at your likely style.
Also you can Test your own code with use own Machine Learning Algorithm codes for own Data and Dataset for own Design.
If you help us , all of this project can change in other computer language , other GUI interface , other option and tools and ...  
If you sponsor to us , we can write for you at your own design on this idea base.


Start
-----
Befor Use Project ensure that ``python 3.7+`` and ``wxpython`` package install on your system .  
you can see requirement package in file text . this project start from scerach 
if you like use Database engain same as MySQL or Oracel ... please install package you need  
and if you like use from other package like SQLalchemy Please send us request


Installation
------------


Appearance of the application
-----------------------------

---------------------
  * Menu and Menubar  
     you can create , edit and delete [Menu Bar](docs/Help/MenuBar.md) and [Menu Item](docs/Help/MenuItem.md)
     Also you can Create [Sub Menu](docs/Help/SubMenu.md) as same as Menu Item 
---------------------
  
  * Toolbar  
    You can Add Edit and Delete [Toolbar](docs/Help/ToolBar.md) with Icon to your application

---------------------
  * Panes  
    You can Design or placed [Pane](docs/Help/Panes.md) in your application
---------------------
  

New Program (How to add)
------------------------

 1. How Connect each [program](docs/Help/Programs.md) to each items
 2. Relationship with [database](docs/Help/Databases.md)

Design Database
---------------

 * Select your engein type
 * SQL Language
 * How Use in source

Add from another source code
----------------------------

* Upload and Create Package
* Downloads and Unpack
* "Fount" Directory

Machine Learning
----------------

1. Design a Panel
2. Add Algorithm
3. Connect to Data
4. Perview Computing

Example
=======
In below you can see some of Example application that you can create by MPT5




Overview
========

Contact to us
==========


